@@ -4,7 +4,7 @@ hypervolume_save_animated_gif <- function(image.size=400, axis=c(0,0,1),rpm=4,du
   tf = basename(tempfile(tmpdir=td))
   
   rgl::par3d(windowRect=c(0,0,image.size,image.size))
-  rgl::movie3d(spin3d(axis=axis,rpm=rpm),duration=duration,fps=fps,movie=tf,dir=td,...)
+  rgl::movie3d(rgl::spin3d(axis=axis,rpm=rpm),duration=duration,fps=fps,movie=tf,dir=td,...)
   
   if(!file.exists(directory.output))
   {
